@@ -238,7 +238,9 @@ class SubTable {
         if (append_mode == kSkipOverlap) {
           if (num_accepted_rows) {
             throw std::invalid_argument(absl::StrFormat(
-                "Overlap was skipped, accepted %d rows so far, but it seems like there are out of order rows afterwards at position %d", num_accepted_rows, i));
+                "Overlap was skipped, accepted %d rows so far, but it seems like there are out of order rows afterwards at position %d",
+                num_accepted_rows,
+                i));
           }
           continue;
         }
@@ -248,7 +250,8 @@ class SubTable {
             "Out of range timestamp for sub table %s, latest inserted was %d, tried to insert %d (append mode: %d)",
             meta_.id().id(),
             index_.last_ts,
-            time[i], append_mode));
+            time[i],
+            append_mode));
       }
       index_.last_ts = time[i];
       if (index_.num_rows % index_density == 0) {
@@ -458,7 +461,9 @@ class SubTable {
                                                bool return_time_column) const {
     const std::string& time_column_name = table_meta_.schema().time_column();
     if (time_selector.has_last_n()) {
-      const Span selected_span = {index_.num_rows -  std::min(time_selector.last_n(), index_.num_rows), index_.num_rows};
+      const Span selected_span =
+          {index_.num_rows - std::min(static_cast<size_t>(time_selector.last_n()), index_.num_rows),
+           index_.num_rows};
       return {
           selected_span,
           ReadRawColumnSingle(column_meta_.at(time_column_name), selected_span)
@@ -471,7 +476,8 @@ class SubTable {
     if (coarse_span.first >= coarse_span.second) {
       return {kEmptySpan, {}};
     }
-    RawColumnData raw_coarse_time = ReadRawColumnSingle(column_meta_.at(time_column_name), coarse_span);
+    RawColumnData
+        raw_coarse_time = ReadRawColumnSingle(column_meta_.at(time_column_name), coarse_span);
     auto* coarse_time = reinterpret_cast<int64_t*>(raw_coarse_time.data);
     const size_t num_rows = coarse_span.second - coarse_span.first;
     GOOGLE_CHECK_EQ(raw_coarse_time.size, sizeof(int64_t) * num_rows);
